@@ -9,8 +9,10 @@
 #' @param totals Boolean. If TRUE, returns totalled data per region up to today's date. If FALSE, returns the full dataset stratified by date and region.
 #' @param include_level_2_regions Boolean. If TRUE, returns data stratified by level 2 regions. If FALSE, stratified by Level 1.
 #' Note that Level 2 region data Sis not always available. In these cases the user will get a warning and the Level 1 data will be returned.
+#' @param localise_regions Logical, defaults to TRUE. Should region names be localised.
 #' @return A tibble with data related to cases, deaths, hospitalisations, recoveries and testing stratified by regions within the given country.
-#' @importFrom dplyr %>% group_by arrange select ungroup do
+#' @importFrom dplyr %>% group_by arrange select ungroup do mutate everything
+#' @importFrom stringr str_trim
 #' @importFrom tidyr drop_na
 #' @importFrom tibble tibble
 #' @export
@@ -20,13 +22,14 @@
 #'  get_regional_data(country = "canada", totals = TRUE, include_level_2_regions = FALSE)
 #' }
 #' 
-get_regional_data <- function(country, totals = FALSE, include_level_2_regions = FALSE){
+get_regional_data <- function(country, totals = FALSE, include_level_2_regions = FALSE,
+                              localise_regions = TRUE){
 
   # Error handling -------------------------------------------------------------------
   if (!(is.character(country))){
     stop("The country variable should be a character variable.")
   }
-
+ 
   if (!(is.logical(totals))){
     stop("The totals variable should be a logical (TRUE/FALSE) variable.")
   }
@@ -34,7 +37,7 @@ get_regional_data <- function(country, totals = FALSE, include_level_2_regions =
   if (!(is.logical(include_level_2_regions))){
     stop("The include_level_2_regions variable should be a logical (TRUE/FALSE) variable.")
   }
-
+ 
   country <- tolower(country)
   countries_with_level_2_regions <- c("belgium",
                                       "brazil",
@@ -56,7 +59,7 @@ get_regional_data <- function(country, totals = FALSE, include_level_2_regions =
                                 "germany" = get_germany_regional_cases_with_level_2,
                                 "uk" = get_uk_regional_cases_with_level_2,
                                 "usa" = get_us_regional_cases_with_level_2,
-                                stop("There is no data for the country entered. It is likely haven't added data
+                                stop("There is no data for the country entered. It is likely we haven't added data
                                    for that country yet, or there was a spelling mistake."))
     
     region_codes_table <- get_region_codes(country)
@@ -76,7 +79,7 @@ get_regional_data <- function(country, totals = FALSE, include_level_2_regions =
                                 "russia" = get_russia_regional_cases,
                                 "uk" = get_uk_regional_cases_only_level_1,
                                 "usa" = get_us_regional_cases_only_level_1,
-                                stop("There is no data for the country entered. It is likely haven't added data
+                                stop("There is no data for the country entered. It is likely we haven't added data
                                    for that country yet, or there was a spelling mistake."))
     
     region_codes_table <- get_region_codes(country)
@@ -85,12 +88,15 @@ get_regional_data <- function(country, totals = FALSE, include_level_2_regions =
   
   # Get the data and region codes for level 1 regions ------------------------------------
   data <- do.call(get_data_function, list())
+  data <- dplyr::mutate(data, region_level_1 = stringr::str_trim(region_level_1, side = "both"))
   data <- data %>% left_join_region_codes(region_codes_table, 
                                        by = c("region_level_1" = "region")) 
   
   # And add level 2 if needed ---------------------------------------------------------
   if (include_level_2_regions) {
-    data <- data %>% left_join_region_codes(region_level_2_codes_table,
+    data <- dplyr::mutate(data, region_level_2 = stringr::str_trim(region_level_2, side = "both"))
+    data <- data %>% 
+      left_join_region_codes(region_level_2_codes_table,
                                          by = c("region_level_2" = "region")) 
   }
 
@@ -113,38 +119,37 @@ get_regional_data <- function(country, totals = FALSE, include_level_2_regions =
   # Totalise and return if totals data is requested ----------------------------------
   if (totals) {
     data <- totalise_data(data, include_level_2_regions = include_level_2_regions) %>%
-      dplyr::arrange(-cases_total) %>%
-      rename_region_column(country) %>%
-      rename_region_code_column(country)
-    return(tibble::tibble(data))
-  }
-
-  # Pad the data set ------------------------------------------------------------------
-  data <- data %>%
-    tidyr::drop_na(date) %>%
-    fill_empty_dates_with_na() %>%
-    complete_cumulative_columns()
-
-  # Select and arrange the data -------------------------------------------------------
-  if (include_level_2_regions) {
+      dplyr::arrange(-cases_total)
+  }else{
+    # Pad the data set ------------------------------------------------------------------
     data <- data %>%
-      dplyr::select(date, region_level_2, level_2_region_code, region_level_1, level_1_region_code, 
-                    cases_new, cases_total, deaths_new, deaths_total,
-                    recovered_new, recovered_total, hosp_new, hosp_total,
-                    tested_new, tested_total) %>%
-      dplyr::arrange(date, region_level_1, region_level_2)
-  } else {
-    data <- data %>%
-    dplyr::select(date, region_level_1, level_1_region_code, cases_new, cases_total, deaths_new, deaths_total,
-                  recovered_new, recovered_total, hosp_new, hosp_total,
-                  tested_new, tested_total) %>%
-    dplyr::arrange(date, region_level_1)
+      tidyr::drop_na(date) %>%
+      fill_empty_dates_with_na() %>%
+      complete_cumulative_columns()
+    
+    # Select and arrange the data -------------------------------------------------------
+    if (include_level_2_regions) {
+      data <- data %>%
+        dplyr::select(date, region_level_2, level_2_region_code, region_level_1, level_1_region_code, 
+                      cases_new, cases_total, deaths_new, deaths_total,
+                      recovered_new, recovered_total, hosp_new, hosp_total,
+                      tested_new, tested_total, dplyr::everything()) %>%
+        dplyr::arrange(date, region_level_1, region_level_2)
+    } else {
+      data <- data %>%
+        dplyr::select(date, region_level_1, level_1_region_code, cases_new, cases_total, deaths_new, deaths_total,
+                      recovered_new, recovered_total, hosp_new, hosp_total,
+                      tested_new, tested_total, dplyr::everything()) %>%
+        dplyr::arrange(date, region_level_1)
+    }
   }
-
+  
   # Rename the region column to country-specific --------------------------------------
-  data <- data %>%
-    rename_region_column(country) %>%
-    rename_region_code_column(country)
-
+  if (localise_regions) {
+    data <- rename_region_column(data, country)
+  }
+  
+  data <- rename_region_code_column(data, country)
+  
   return(tibble::tibble(data))
 }
